<?php

namespace Eform\Vehicle\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Eform\Vehicle\Actions\VehicleAction;
use Eform\Vehicle\Http\Requests\VehicleActionRequest;
use Eform\Vehicle\Http\Resources\VehicleResource;
use Eform\Vehicle\Models\Vehicle;

/**
 * Admin web controller class.
 */
class VehicleActionController extends BaseController
{

    /**
     * Action controller function for vehicle.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(VehicleActionRequest $request, Vehicle $vehicle, $action)
    {
        try {
            $request = $request->all();
            $vehicle = VehicleAction::run($action, $vehicle, $request);

            $data = new VehicleResource($vehicle);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('vehicle::vehicle.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('vehicle/vehicle/' . $vehicle->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('vehicle/vehicle/' . $vehicle->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
