<?php

namespace Eform\Vehicle\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Eform\Vehicle\Actions\VehicleExim;
use Eform\Vehicle\Http\Requests\VehicleEximRequest;

/**
 * Admin web controller class.
 */
class VehicleEximController extends BaseController
{
    /**
     * Action controller function for vehicle.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(VehicleEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = VehicleExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('vehicle:vehicle.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('vehicle/vehicle/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('vehicle/vehicle/' . $exim))
                ->redirect();
        }
    }
}
