<?php
namespace Eform\Vehicle\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Eform\Vehicle\Events\VehicleAction as VehicleActionEvent;
use Eform\Vehicle\Models\Vehicle;

class VehicleAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $vehicle;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param VehicleActionEvent $vehicle
     */
    public function __construct(VehicleActionEvent $vehicle)
    {
        $this->action = $event->action;
        $this->vehicle = $vehicle;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Vehicle Approved - ' . config('app.name'))
            ->view('vehicle::vehicle.email.action', ['data' => $this->vehicle]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
