<?php

namespace Eform\Vehicle\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Eform\Vehicle\Models\Vehicle;

class VehiclePolicy
{

    use VehicleAction;
    use VehicleExim;

    /**
     * Determine if the given user can view the vehicle.
     *
     * @param Authenticatable $user
     * @param Vehicle $vehicle
     *
     * @return bool
     */
    public function view(Authenticatable $user, Vehicle $vehicle)
    {
        if ($authUser->canDo('vehicle.vehicle.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $vehicle->is_owner;
    }

    /**
     * Determine if the given user can create a vehicle.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('vehicle.vehicle.create');
    }

    /**
     * Determine if the given user can update the given vehicle.
     *
     * @param Authenticatable $user
     * @param Vehicle $vehicle
     *
     * @return bool
     */
    public function update(Authenticatable $user, Vehicle $vehicle)
    {
        if ($user->canDo('vehicle.vehicle.edit') && $user->isAdmin()) {
            return true;
        }

        return $vehicle->is_owner;
    }

    /**
     * Determine if the given user can delete the given vehicle.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Vehicle $vehicle)
    {
        return $vehicle->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
